@@ -1,7 +1,7 @@
 /*
  * lftp and utils
  *
- * Copyright (c) 1996-2001 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2010 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: FileAccess.h,v 1.111 2009/04/16 14:10:56 lav Exp $ */
+/* $Id: FileAccess.h,v 1.115 2010/04/29 11:00:41 lav Exp $ */
 
 #ifndef FILEACCESS_H
 #define FILEACCESS_H
@@ -32,6 +32,7 @@
 #include "ResMgr.h"
 #include "FileSet.h"
 #include "ArgV.h"
+#include "ProtoLog.h"
 
 #define FILE_END     ((off_t)-1L)
 #define UNKNOWN_POS  ((off_t)-1L)
@@ -42,7 +43,7 @@ class NoGlob;
 class DirList;
 class FileAccessRef;
 
-class FileAccess : public SMTask, public ResClient
+class FileAccess : public SMTask, public ResClient, protected ProtoLog
 {
    static bool class_inited;
 public:
@@ -132,12 +133,6 @@ protected:
    FileTimestamp *opt_date;
    off_t  *opt_size;
 
-   static void NonBlock(int fd);
-   static void CloseOnExec(int fd);
-
-   static void Log2(int level,xstring& str);
-   static void Log3(int level,const char *prefix,const char *str);
-
    time_t try_time;
    int retries;
 
@@ -150,7 +145,7 @@ protected:
    int	 saved_errno;
 
    void	 ExpandTildeInCWD();
-   const char *ExpandTildeStatic(const char *s);
+   const char *ExpandTildeStatic(const char *s) const;
 
    xstring real_cwd;
    void set_real_cwd(const char *c)
@@ -189,12 +184,12 @@ protected:
 
    FileAccess *next;
    static FileAccess *chain;
-   FileAccess *FirstSameSite() { return NextSameSite(0); }
-   FileAccess *NextSameSite(FileAccess *);
+   FileAccess *FirstSameSite() const { return NextSameSite(0); }
+   FileAccess *NextSameSite(FileAccess *) const;
 
-   StringSet *MkdirMakeSet(); // splits the path for mkdir -p
+   StringSet *MkdirMakeSet() const; // splits the path for mkdir -p
 
-   int device_prefix_len(const char *path);
+   int device_prefix_len(const char *path) const;
 
 public:
    virtual const char *GetProto() const = 0; // http, ftp, file etc
@@ -373,11 +368,6 @@ public:
 
    static void ClassInit();
    static void ClassCleanup();
-
-   static void LogError(int level,const char *fmt,...) PRINTF_LIKE(2,3);
-   static void LogNote(int level,const char *fmt,...) PRINTF_LIKE(2,3);
-   static void LogRecv(int level,const char *line);
-   static void LogSend(int level,const char *line);
 };
 
 // shortcut
