@@ -1,7 +1,7 @@
 /*
  * lftp - file transfer program
  *
- * Copyright (c) 1999-2005 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1999-2010 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: FileCopy.cc,v 1.153 2009/04/27 07:45:26 lav Exp $ */
+/* $Id: FileCopy.cc,v 1.157 2010/04/29 11:00:41 lav Exp $ */
 
 /* FileCopyPeer behaviour:
     1) when suspended, does nothing
@@ -848,6 +848,11 @@ int FileCopyPeerFA::Do()
 	       {
 		  try_time=session->GetTryTime();
 		  retries=session->GetRetries();
+		  off_t pos=session->GetRealPos();
+		  if(upload_watermark<pos) {
+		     upload_watermark=pos;
+		     retries=-1;
+		  }
 		  Log::global->Format(10,"try_time=%ld, retries=%d\n",(long)try_time,retries);
 		  session->Close();
 		  if(can_seek && seek_pos>0)
@@ -982,9 +987,9 @@ void FileCopyPeerFA::OpenSession()
    session->SetLimit(range_limit);
    if(mode==PUT)
    {
-      if(try_time!=0)
+      if(try_time!=NO_DATE)
 	 session->SetTryTime(try_time);
-      if(retries!=0)
+      if(retries>=0)
 	 session->SetRetries(retries+1);
       if(e_size!=NO_SIZE && e_size!=NO_SIZE_YET)
 	 session->SetSize(e_size);
@@ -996,7 +1001,7 @@ void FileCopyPeerFA::OpenSession()
       session->AsciiTransfer();
    if(want_size && size==NO_SIZE_YET)
       session->WantSize(&size);
-   if(want_date && (date==NO_DATE_YET || date.ts_prec>1))
+   if(want_date && (date==NO_DATE_YET || date.ts_prec>0))
       session->WantDate(&date);
    if(mode==GET)
       SaveRollback(seek_pos);
@@ -1105,8 +1110,8 @@ int FileCopyPeerFA::Get_LL(int len)
 	    size=NO_SIZE_YET;
 	    date=NO_DATE_YET;
 
-	    try_time=0;
-	    retries=0;
+	    try_time=NO_DATE;
+	    retries=-1;
 	    current->Timeout(0); // retry with new location.
 	    return 0;
 	 }
@@ -1145,6 +1150,11 @@ int FileCopyPeerFA::Put_LL(const char *buf,int len)
       {
 	 try_time=session->GetTryTime();
 	 retries=session->GetRetries();
+	 off_t pos=session->GetRealPos();
+	 if(upload_watermark<pos) {
+	    upload_watermark=pos;
+	    retries=-1;
+	 }
 	 Log::global->Format(10,"try_time=%ld, retries=%d\n",(long)try_time,retries);
 	 session->Close();
 	 if(can_seek && seek_pos>0)
@@ -1198,8 +1208,9 @@ off_t FileCopyPeerFA::GetRealPos()
 void FileCopyPeerFA::Init()
 {
    fxp=false;
-   try_time=0;
-   retries=0;
+   try_time=NO_DATE;
+   retries=-1;
+   upload_watermark=0;
    redirections=0;
    can_seek=true;
    can_seek0=true;
@@ -1379,9 +1390,13 @@ int FileCopyPeerFDStream::Do()
       {
 	 if(suggested_filename && stream && stream->full_name && auto_rename)
 	 {
-	    debug((5,"copy: renaming `%s' to `%s'\n",stream->full_name.get(),suggested_filename.get()));
-	    if(rename(stream->full_name,dir_file(dirname(stream->full_name),suggested_filename))==-1)
-	       debug((3,"rename(%s, %s): %s\n",stream->full_name.get(),suggested_filename.get(),strerror(errno)));
+	    const char *new_name=dir_file(dirname(stream->full_name),suggested_filename);
+	    struct stat st;
+	    if(lstat(new_name,&st)==-1 && errno==ENOENT) {
+	       debug((5,"copy: renaming `%s' to `%s'\n",stream->full_name.get(),suggested_filename.get()));
+	       if(rename(stream->full_name,new_name)==-1)
+		  debug((3,"rename(%s, %s): %s\n",stream->full_name.get(),new_name,strerror(errno)));
+	    }
 	 }
 	 done=true;
 	 m=MOVED;
@@ -1727,8 +1742,14 @@ void FileCopyPeerFDStream::Kill(int sig)
 
 FileCopyPeerFDStream *FileCopyPeerFDStream::NewPut(const char *file,bool cont)
 {
-   return new FileCopyPeerFDStream(new FileStream(file,O_WRONLY|O_CREAT
-				    |(cont?0:O_TRUNC)),FileCopyPeer::PUT);
+   int flags=O_WRONLY|O_CREAT;
+   if(!cont) {
+      flags|=O_TRUNC;
+      if(!ResMgr::QueryBool("xfer:clobber",0))
+	 flags|=O_EXCL;
+   }
+   return new FileCopyPeerFDStream(new FileStream(file,flags),
+				    FileCopyPeer::PUT);
 }
 FileCopyPeerFDStream *FileCopyPeerFDStream::NewGet(const char *file)
 {
