@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: FileSet.cc,v 1.68 2009/03/03 13:31:39 lav Exp $ */
+/* $Id: FileSet.cc,v 1.71 2009/10/09 14:46:57 lav Exp $ */
 
 #include <config.h>
 #include "FileSet.h"
@@ -43,6 +43,10 @@
 #include "IdNameCache.h"
 #include "PatternSet.h"
 
+#ifdef HAVE_SYS_STATFS_H
+# include <sys/statfs.h>
+#endif
+
 #define fnum files.count()
 
 void  FileInfo::Merge(const FileInfo& f)
@@ -678,7 +682,6 @@ check_again:
       t=FileInfo::DIRECTORY;
    else if(S_ISREG(st.st_mode))
       t=FileInfo::NORMAL;
-#ifdef HAVE_LSTAT
    else if(S_ISLNK(st.st_mode))
    {
       if(follow_symlinks)
@@ -689,12 +692,17 @@ check_again:
       }
       t=FileInfo::SYMLINK;
    }
-#endif
    else
       return;   // ignore other type files
 
    SetSize(st.st_size);
-   SetDate(st.st_mtime,0);
+   int prec=0;
+#if defined(HAVE_STATFS) && defined(MSDOS_SUPER_MAGIC)
+   struct statfs stfs;
+   if(statfs(name,&stfs)!=-1 && stfs.f_type==MSDOS_SUPER_MAGIC)
+      prec=1;  // MS-DOS fs has 2-second resolution
+#endif
+   SetDate(st.st_mtime,prec);
    SetMode(st.st_mode&07777);
    SetType(t);
    SetNlink(st.st_nlink);
@@ -702,7 +710,6 @@ check_again:
    SetUser(PasswdCache::LookupS(st.st_uid));
    SetGroup(GroupCache::LookupS(st.st_gid));
 
-#ifdef HAVE_LSTAT
    if(t==SYMLINK)
    {
       char *buf=(char*)alloca(st.st_size+1);
@@ -713,7 +720,6 @@ check_again:
 	 SetSymlink(buf);
       }
    }
-#endif /* HAVE_LSTAT */
 }
 
 /* parse_ls_line: too common procedure to make it protocol specific */
@@ -845,7 +851,7 @@ FileInfo *FileInfo::parse_ls_line(const char *line_c,const char *tz)
    if(!name)
       ERR;
 
-   // there are ls which outputs extra space after year.
+   // there are ls which output extra space after year.
    if(year_anomaly && *name==' ')
       name++;
 
