@@ -1,7 +1,7 @@
 /*
  * lftp and utils
  *
- * Copyright (c) 1996-2000 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2010 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: GetJob.cc,v 1.32 2008/11/27 05:56:18 lav Exp $ */
+/* $Id: GetJob.cc,v 1.35 2010/04/29 11:00:42 lav Exp $ */
 
 #include <config.h>
 #include <sys/types.h>
@@ -34,7 +34,7 @@
 #include "ArgV.h"
 #include "url.h"
 
-ResDecl res_clobber	("xfer:clobber",     "yes",ResMgr::BoolValidate,ResMgr::NoClosure);
+ResDecl res_clobber	("xfer:clobber",     "no", ResMgr::BoolValidate,ResMgr::NoClosure);
 ResDecl res_make_backup	("xfer:make-backup", "yes",ResMgr::BoolValidate,ResMgr::NoClosure);
 
 #define super CopyJobEnv
@@ -64,7 +64,8 @@ FileCopyPeer *GetJob::SrcLocal(const char *src)
 }
 FileCopyPeer *GetJob::DstLocal(const char *dst)
 {
-   int flags=O_WRONLY|O_CREAT|(truncate_target_first?O_TRUNC:0);
+   bool clobber=res_clobber.QueryBool(0);
+   int flags=O_WRONLY|O_CREAT|(truncate_target_first?O_TRUNC:0)|(clobber?0:O_EXCL);
    dst=expand_home_relative(dst);
    const char *f=(cwd && dst[0]!='/') ? dir_file(cwd,dst) : dst;
    if(truncate_target_first && res_make_backup.QueryBool(0))
@@ -75,7 +76,7 @@ FileCopyPeer *GetJob::DstLocal(const char *dst)
       {
 	 if(st.st_size>0 && S_ISREG(st.st_mode))
 	 {
-	    if(!res_clobber.QueryBool(0))
+	    if(!clobber)
 	    {
 	       eprintf(_("%s: %s: file already exists and xfer:clobber is unset\n"),op,dst);
 	       errors++;
