@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: MirrorJob.cc,v 1.169 2009/05/13 08:40:18 lav Exp $ */
+/* $Id: MirrorJob.cc,v 1.171 2009/12/21 16:31:53 lav Exp $ */
 
 #include <config.h>
 
@@ -436,7 +436,6 @@ void  MirrorJob::HandleFile(FileInfo *file)
 	       goto skip;
 	 }
 
-#ifdef HAVE_LSTAT
 	 if(file->defined&file->SYMLINK)
 	 {
 	    struct stat st;
@@ -467,7 +466,6 @@ void  MirrorJob::HandleFile(FileInfo *file)
 	    if(res==-1)
 	       eprintf("mirror: symlink(%s): %s\n",target_name,strerror(errno));
 	 }
-#endif /* LSTAT */
 	 break;
       }
    case FileInfo::UNKNOWN:
@@ -1403,7 +1401,7 @@ CMD(mirror)
       flags|=MirrorJob::RETR_SYMLINKS;
 
    args->rewind();
-   while((opt=args->getopt_long("esi:x:I:X:nrpcRvN:LPa",mirror_opts,0))!=EOF)
+   while((opt=args->getopt_long("esi:x:I:X:nrpcRvN:LP:a",mirror_opts,0))!=EOF)
    {
       switch(opt)
       {
