@@ -1,7 +1,7 @@
 /*
  * lftp and utils
  *
- * Copyright (c) 1996-2005 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2010 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: ResMgr.cc,v 1.74 2008/11/27 05:56:26 lav Exp $ */
+/* $Id: ResMgr.cc,v 1.78 2010/04/29 11:00:42 lav Exp $ */
 
 #include <config.h>
 
@@ -481,6 +481,8 @@ const char *ResMgr::UNumberValidate(xstring_c *value)
 }
 unsigned long long ResValue::to_unumber(unsigned long long max)
 {
+   if (is_nil())
+      return 0;
    const char *end=s;
    unsigned long long v=strtoull(s,const_cast<char**>(&end),0);
    unsigned long long m=get_power_multiplier(*end);
@@ -491,8 +493,10 @@ unsigned long long ResValue::to_unumber(unsigned long long max)
 }
 long long ResValue::to_number(long long min,long long max)
 {
+   if (is_nil())
+      return 0;
    const char *end=s;
-   long long v=strtoull(s,const_cast<char**>(&end),0);
+   long long v=strtoll(s,const_cast<char**>(&end),0);
    long long m=get_power_multiplier(*end);
    long long vm=v*m;
    if(vm/m!=v)
@@ -781,28 +785,16 @@ const char *Range::scale(long long *value,char suf)
    return 0;
 }
 
-#if !HAVE_DECL_RANDOM
-CDECL long random();
-CDECL void srandom(unsigned seed);
-#endif
-
 long long Range::Random()
 {
-   static bool init=false;
-   if(!init)
-   {
-      srandom(time(NULL)+getpid());
-      init=true;
-   }
+   random_init();
 
    if(no_start && no_end)
       return random();
    if(no_end)
       return start+random();
 
-   // interval [0;1)
-   double mult=random()/2147483648.0;
-   return start + (long long)((end-start+1)*mult);
+   return start + (long long)((end-start+1)*random01());
 }
 
 const char *ResMgr::RangeValidate(xstring_c *s)
