@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: Resolver.cc,v 1.84 2009/01/27 14:43:12 lav Exp $ */
+/* $Id: Resolver.cc,v 1.89 2009/11/17 08:16:44 lav Exp $ */
 
 #include <config.h>
 
@@ -45,6 +45,10 @@
 # include <resolv.h>
 #endif
 
+#ifdef DNSSEC_LOCAL_VALIDATION
+# include "validator/validator.h"
+#endif
+
 #include "xstring.h"
 #include "ResMgr.h"
 #include "log.h"
@@ -94,6 +98,7 @@ static const address_family af_list[]=
 
 ResolverCache *Resolver::cache;
 
+
 Resolver::Resolver(const char *h,const char *p,const char *defp,
 		   const char *ser,const char *pr)
    : hostname(h), portname(p), service(ser), proto(pr), defport(defp)
@@ -139,7 +144,7 @@ int   Resolver::Do()
       cache->Find(hostname,portname,defport,service,proto,&a,&n);
       if(a && n>0)
       {
-	 FA::LogNote(10,"dns cache hit");
+	 LogNote(10,"dns cache hit");
 	 addr.nset(a,n);
 	 done=true;
 	 return MOVED;
@@ -163,7 +168,7 @@ int   Resolver::Do()
 	 fcntl(pipe_to_child[0],F_SETFD,FD_CLOEXEC);
 	 fcntl(pipe_to_child[1],F_SETFD,FD_CLOEXEC);
 	 m=MOVED;
-	 FA::LogNote(4,_("Resolving host address..."));
+	 LogNote(4,_("Resolving host address..."));
       }
 
       if(!w && !buf)
@@ -205,7 +210,7 @@ int   Resolver::Do()
    {
       if(!buf)
       {
-	 FA::LogNote(4,_("Resolving host address..."));
+	 LogNote(4,_("Resolving host address..."));
 	 buf=new IOBuffer(IOBuffer::GET);
 	 DoGethostbyname();
 	 if(deleting)
@@ -254,7 +259,7 @@ int   Resolver::Do()
       if(use_fork)
       {
 	 // e.g. under gdb child fails.
-	 FA::LogError(4,"child failed, retrying with dns:use-fork=no");
+	 LogError(4,"child failed, retrying with dns:use-fork=no");
 	 use_fork=false;
 	 buf=0;
 	 return MOVED;
@@ -279,7 +284,7 @@ int   Resolver::Do()
 	    report.append(", ");
       }
    }
-   FA::LogNote(4,"%s",report.get());
+   LogNote(4,"%s",report.get());
 
    return MOVED;
 }
@@ -492,9 +497,22 @@ void Resolver::LookupSRV_RR()
 	    return;
       }
       time(&try_time);
+
+#ifndef DNSSEC_LOCAL_VALIDATION
       len=res_search(srv_name, C_IN, T_SRV, answer, sizeof(answer));
       if(len>=0)
 	 break;
+#else
+      val_status_t val_status;
+      bool require_trust = ResMgr::QueryBool("dns:strict-dnssec",hostname);
+      len=val_res_search(NULL, srv_name, C_IN, T_SRV, answer, sizeof(answer), &val_status);
+      if(len>=0) {
+          if(require_trust && !val_istrusted(val_status))
+              return;
+          else
+              break;
+      }
+#endif
 #ifdef HAVE_H_ERRNO
       if(h_errno!=TRY_AGAIN)
 	 return;
@@ -702,7 +720,20 @@ void Resolver::LookupOne(const char *name)
       a_hint.ai_flags	    = AI_PASSIVE;
       a_hint.ai_family	    = PF_UNSPEC;
 
+#ifndef DNSSEC_LOCAL_VALIDATION
       ainfo_res	= getaddrinfo(name, NULL, &a_hint, &ainfo);
+#else
+      val_status_t val_status;
+      bool require_trust=ResMgr::QueryBool("dns:strict-dnssec",name);
+      ainfo_res	= val_getaddrinfo(NULL, name, NULL, &a_hint, &ainfo,
+                                  &val_status);
+      if(VAL_GETADDRINFO_HAS_STATUS(ainfo_res)
+      && !val_istrusted(val_status) && require_trust) {
+          // untrusted answer
+          error = _("DNS resoloution not trusted.");
+          break;
+      }
+#endif
 
       if(ainfo_res == 0)
       {
