@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: Resolver.h,v 1.27 2009/01/27 14:17:57 lav Exp $ */
+/* $Id: Resolver.h,v 1.30 2009/10/26 13:26:39 lav Exp $ */
 
 #ifndef RESOLVER_H
 #define RESOLVER_H
@@ -29,7 +29,7 @@
 #include "Cache.h"
 #include "network.h"
 
-class Resolver : public SMTask
+class Resolver : public SMTask, protected ProtoLog
 {
    xstring hostname;
    xstring portname;
