@@ -1,7 +1,7 @@
 /*
  * lftp and utils
  *
- * Copyright (c) 1996-2009 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2010 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: commands.cc,v 1.294 2009/03/20 12:27:03 lav Exp $ */
+/* $Id: commands.cc,v 1.299 2010/04/29 11:00:42 lav Exp $ */
 
 #include <config.h>
 
@@ -93,7 +93,7 @@ CMD(ver);   CMD(close);  CMD(bookmark);CMD(lftp);
 CMD(echo);  CMD(suspend);CMD(sleep);   CMD(slot);
 CMD(at);    CMD(find);   CMD(command); CMD(module);
 CMD(lpwd);  CMD(glob);	 CMD(chmod);   CMD(queue);
-CMD(repeat);CMD(get1);   CMD(tasks);
+CMD(repeat);CMD(get1);   CMD(tasks);   CMD(torrent);
 
 #ifdef MODULE_CMD_MIRROR
 # define cmd_mirror 0
@@ -103,6 +103,9 @@ CMD(repeat);CMD(get1);   CMD(tasks);
 # define cmd_at     0
 # define cmd_repeat 0
 #endif
+#ifdef MODULE_CMD_TORRENT
+# define cmd_torrent 0
+#endif
 
 #define S "\001"
 
@@ -118,7 +121,7 @@ const struct CmdExec::cmd_rec CmdExec::static_cmd_table[]=
 	 N_("Define or undefine alias <name>. If <value> omitted,\n"
 	 "the alias is undefined, else is takes the value <value>.\n"
          "If no argument is given the current aliases are listed.\n")},
-   {"anon",    cmd_anon,   "anon",
+   {"anon",    cmd_anon,   0,
 	 N_("anon - login anonymously (by default)\n")},
    {"at",      cmd_at},
    {"bookmark",cmd_bookmark,N_("bookmark [SUBCMD]"),
@@ -458,6 +461,7 @@ const struct CmdExec::cmd_rec CmdExec::static_cmd_table[]=
    {"source",  cmd_source, N_("source <file>"),
 	 N_("Execute commands recorded in file <file>\n")},
    {"suspend", cmd_suspend},
+   {"torrent", cmd_torrent, N_("torrent [-O <dir>] <file>")},
    {"user",    cmd_user,   N_("user <user|URL> [<pass>]"),
 	 N_("Use specified info for remote login. If you specify URL, the password\n"
 	 "will be cached for future usage.\n")},
@@ -476,9 +480,8 @@ const struct CmdExec::cmd_rec CmdExec::static_cmd_table[]=
 	 N_("Same as more, but filter each file through bzcat\n")},
 
    {".tasks",  cmd_tasks,  0,0},
-
-   {NULL,NULL}
 };
+const int CmdExec::static_cmd_table_length=sizeof(static_cmd_table)/sizeof(static_cmd_table[0]);
 
 #define charcasecmp(a,b) (tolower((unsigned char)(a))-tolower((unsigned char)(b)))
 // returns:
@@ -988,9 +991,9 @@ Job *CmdExec::builtin_open()
 	    if(nrc)
 	    {
 	       if(!user)
-		  FA::LogNote(3,"using user `%s' and password from ~/.netrc",nrc->user.get());
+		  ProtoLog::LogNote(3,"using user `%s' and password from ~/.netrc",nrc->user.get());
 	       else
-		  FA::LogNote(3,"using password from ~/.netrc");
+		  ProtoLog::LogNote(3,"using password from ~/.netrc");
 	       user=nrc->user;
 	       pass=nrc->pass;
 	    }
@@ -2524,27 +2527,38 @@ void CmdExec::print_cmd_help(const char *cmd)
 void CmdExec::print_cmd_index()
 {
    int i=0;
-   const char *c1;
    const cmd_rec *cmd_table=dyn_cmd_table?dyn_cmd_table.get():static_cmd_table;
-   const int count=dyn_cmd_table?dyn_cmd_table.count():1024;
-   while(i<count && cmd_table[i].name)
+   const int count=dyn_cmd_table?dyn_cmd_table.count():static_cmd_table_length;
+   int width=fd_width(1);
+   int pos=0;
+   const int align=37;
+   const int first_align=4;
+   while(i<count)
    {
-      while(cmd_table[i].name && !cmd_table[i].short_desc)
+      while(i<count && !cmd_table[i].short_desc)
 	 i++;
-      if(!cmd_table[i].name)
+      if(i>=count)
 	 break;
-      c1=cmd_table[i].short_desc;
+      const char *c1=gettext(cmd_table[i].short_desc);
       i++;
-      while(cmd_table[i].name && !cmd_table[i].short_desc)
-	 i++;
-      if(cmd_table[i].name)
-      {
-	 printf("\t%-35s %s\n",gettext(c1),gettext(cmd_table[i].short_desc));
-	 i++;
+      int w1=mbswidth(c1,0);
+
+      int pad=0;
+      if(pos<first_align)
+	 pad=first_align-pos;
+      else if(pos>first_align)
+	 pad=align-(pos-first_align)%align;
+      if(pos>first_align && pos+pad+w1>=width) {
+	 printf("\n");
+	 pos=0;
+	 pad=first_align;
       }
-      else
-	 printf("\t%s\n",_(c1));
+
+      printf("%*s%s",pad,"",c1);
+      pos+=pad+w1;
    }
+   if(pos>0)
+      printf("\n");
 }
 
 CMD(help)
@@ -2570,7 +2584,7 @@ CMD(help)
 CMD(ver)
 {
    printf(
-      _("LFTP | Version %s | Copyright (c) 1996-%d Alexander V. Lukyanov\n"),VERSION,2009);
+      _("LFTP | Version %s | Copyright (c) 1996-%d Alexander V. Lukyanov\n"),VERSION,2010);
    printf("\n");
    printf(
       _("LFTP is free software: you can redistribute it and/or modify\n"
@@ -3283,7 +3297,7 @@ CMD(get1)
       dst_peer=FileCopyPeerFDStream::NewPut(dst,cont||target_region_begin>0);
    else
       dst_peer=new FileCopyPeerFA(&dst_url,FA::STORE);
-   dst_peer->AutoRename(auto_rename);
+   dst_peer->AutoRename(auto_rename && ResMgr::QueryBool("xfer:auto-rename",0));
    if(!cont && (target_region_begin>0 || target_region_end!=FILE_END))
       dst_peer->SetRange(target_region_begin,target_region_end);
 
