@@ -5,7 +5,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: keyvalue.cc,v 1.17 2006/02/06 10:57:31 lav Exp $ */
+/* $Id: keyvalue.cc,v 1.22 2008/11/27 05:56:37 lav Exp $ */
 
 #include <config.h>
 #include "keyvalue.h"
@@ -29,10 +29,8 @@
 
 int KeyValueDB::Read(int fd)
 {
-   int key_size=16;
-   char *key=(char*)xmalloc(key_size);
-   int value_size=16;
-   char *value=(char*)xmalloc(value_size);
+   xstring key;
+   xstring value;
 
    int c;
 
@@ -51,27 +49,18 @@ int KeyValueDB::Read(int fd)
       if(c=='\n')
 	 continue;   // next line
 
-      char *store=key;
-
+      key.truncate(0);
       for(;;)
       {
-	 if(store>=key+key_size-1)
-	 {
-	    int shift=store-key;
-	    key=(char*)xrealloc(key,key_size*=2);
-	    store=key+shift;
-	 }
-	 *store++=c;
-
+	 key.append(c);
 	 c=getc(f);
 	 if(c==EOF)
 	    break;
 	 if(c==' ' || c=='\t' || c=='\n')
 	    break;
       }
-      *store=0;
 
-      if(c==EOF || c=='\n' || store==key)
+      if(c==EOF || c=='\n' || key.length()==0)
 	 break;	// invalid line
 
       // skip space in mid
@@ -81,25 +70,16 @@ int KeyValueDB::Read(int fd)
       if(c==EOF || c=='\n')
 	 break;
 
-      store=value;
-
+      value.truncate(0);
       for(;;)
       {
-	 if(store>=value+value_size-1)
-	 {
-	    int shift=store-value;
-	    value=(char*)xrealloc(value,value_size*=2);
-	    store=value+shift;
-	 }
-	 *store++=c;
-
+	 value.append(c);
 	 c=getc(f);
 	 if(c==EOF)
 	    break;
 	 if(c=='\n')
 	    break;
       }
-      *store=0;
 
       Add(key,value);
 
@@ -107,8 +87,6 @@ int KeyValueDB::Read(int fd)
 	 break;
    }
    fclose(f);
-   xfree(key);
-   xfree(value);
    return 0;
 }
 
@@ -150,38 +128,25 @@ char *KeyValueDB::Format(StringMangler value_mangle)
 
    Pair *p;
    int max_key_len=0;
-   size_t size_required=0;
-   int n=0;
 
    for(p=chain; p; p=p->next)
    {
       int len=strlen(p->key);
       if(len>max_key_len)
 	 max_key_len=len;
-      size_required+=1+strlen(value_mangle(p->value))+1;
-      n++;
    }
-   size_required+=max_key_len*n;
    max_key_len&=~7;  // save some bytes
 
-   char *buf=(char*)xmalloc(size_required+1);
-   char *store=buf;
-
+   xstring buf("");
    for(p=chain; p; p=p->next)
-   {
-      sprintf(store,"%-*s\t%s\n",max_key_len,p->key,value_mangle(p->value));
-      store+=strlen(store);
-   }
-   *store=0; // this is for chain==0 case
-
-   return buf;
+      buf.appendf("%-*s\t%s\n",max_key_len,p->key.get(),value_mangle(p->value));
+   return buf.borrow();
 }
 
 int KeyValueDB::Write(int fd)
 {
-   char *buf=Format();
+   xstring_ca buf(Format());
    int res=write(fd,buf,strlen(buf));
-   xfree(buf);
    close(fd);
    return res;
 }
@@ -215,7 +180,7 @@ KeyValueDB::Pair **KeyValueDB::LookupPair(const char *key) const
 const char *KeyValueDB::Lookup(const char *key) const
 {
    const Pair * const*p=LookupPair(key);
-   return p ? (*p)->value : 0;
+   return p ? (*p)->value.get() : 0;
 }
 
 int KeyValueDB::Lock(int fd,int type)
