@@ -5,7 +5,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -18,13 +18,14 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: log.h,v 1.9 2006/04/19 09:48:08 lav Exp $ */
+/* $Id: log.h,v 1.14 2009/03/20 12:26:48 lav Exp $ */
 
 #ifndef LOG_H
 #define LOG_H
 
 #include <unistd.h>
 #include <stdlib.h>
+#include <stdarg.h>
 #include "SMTask.h"
 
 class Log : public SMTask
@@ -46,31 +47,24 @@ class Log : public SMTask
 	 output=-1;
 	 need_close_output=false;
       }
-
-protected:
-   ~Log();
+   bool WillOutput(int l);
 
 public:
-   static Log *global;
+   static SMTaskRef<Log> global;
 
    bool enabled;
    int level;
 
+   void DoWrite(const char *str);
    void Write(int l,const char *str);
    void Format(int l,const char *fmt,...) PRINTF_LIKE(3,4);
+   void vFormat(int l,const char *fmt,va_list v);
 
    void SetLevel(int l) { level=l; }
    void Enable()  { enabled=true;  }
    void Disable() { enabled=false; }
 
-   void SetOutput(int o,bool need_close)
-      {
-	 CloseOutput();
-	 output=o;
-	 need_close_output=need_close;
-	 if(output!=-1)
-	    tty=isatty(output);
-      }
+   void SetOutput(int o,bool need_close);
 
    void SetCB(tty_cb_t cb) { tty_cb=cb; }
 
@@ -78,6 +72,7 @@ public:
 
    void Init();
    Log() { Init(); }
+   ~Log();
 
    int Do();
 
