@@ -5,7 +5,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: mgetJob.cc,v 1.26 2008/08/05 12:10:16 lav Exp $ */
+/* $Id: mgetJob.cc,v 1.30 2009/10/09 14:46:57 lav Exp $ */
 
 #include <config.h>
 #include <sys/types.h>
@@ -122,7 +122,9 @@ void mgetJob::LocalGlob(const char *p)
    glob(p,0,0,&pglob);
    if(pglob.gl_pathc==0)
    {
-      fprintf(stderr,_("%s: no files found\n"),p);
+      fprintf(stderr,_("%s: %s: no files found\n"),op,p);
+      count++;
+      errors++;
       return;
    }
    for(i=0; i<(int)pglob.gl_pathc; i++)
@@ -169,11 +171,11 @@ int mgetJob::Do()
 	 m_args=0;
 	 if(mkdir_args)
 	 {
+	    xstring_ca cmdline(mkdir_args->Combine());
 	    mkdir_job=new mkdirJob(Clone(),mkdir_args.borrow());
+	    mkdir_job->cmdline.set_allocated(cmdline.borrow());
 	    mkdir_job->BeQuiet();
-	    AddWaiting(mkdir_job.get_non_const());
-	    mkdir_job->SetParentFg(this);
-	    mkdir_job->cmdline.set_allocated(mkdir_args->Combine());
+	    AddWaiting(mkdir_job);
 	 }
 	 return MOVED;
       }
@@ -189,7 +191,9 @@ int mgetJob::Do()
 
    if(rg->Error())
    {
-      fprintf(stderr,"rglob: %s\n",rg->ErrorText());
+      fprintf(stderr,"%s: %s: %s\n",op,rg->GetPattern(),rg->ErrorText());
+      count++;
+      errors++;
       goto next;
    }
 
@@ -201,7 +205,9 @@ int mgetJob::Do()
    FileSet *files=rg->GetResult();
    if(files->get_fnum()==0)
    {
-      fprintf(stderr,_("%s: no files found\n"),rg->GetPattern());
+      fprintf(stderr,_("%s: %s: no files found\n"),op,rg->GetPattern());
+      count++;
+      errors++;
       goto next;
    }
    do {
