@@ -1,11 +1,11 @@
 /*
  * lftp and utils
  *
- * Copyright (c) 1996-2005 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2010 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: misc.cc,v 1.95 2008/07/23 08:46:12 lav Exp $ */
+/* $Id: misc.cc,v 1.100 2010/04/29 11:00:43 lav Exp $ */
 
 #include <config.h>
 #include "xmalloc.h"
@@ -32,6 +32,7 @@
 #include <time.h>
 #include <ctype.h>
 #include <sys/ioctl.h>
+#include <fcntl.h>
 
 #ifdef HAVE_TERMIOS_H
 #include <termios.h>
@@ -63,11 +64,7 @@ const char *dir_file(const char *dir,const char *file)
    if(file[0]=='/')
       return file;
 
-   static xstring buf;
-
-   if(buf && dir==buf) // it is possible to dir_file(dir_file(dir,dir),file)
-      dir=alloca_strdup(dir);
-
+   xstring& buf=xstring::get_tmp();
    size_t len=strlen(dir);
    if(len==0)
       return buf.set(file);
@@ -569,7 +566,7 @@ char *Subst(const char *txt, const subst_t *s)
       if(ch=='\\' && *txt && *txt!='\\')
       {
 	 ch=*txt++;
-	 if(isdigit(ch) && ch != '8' && ch != '9') {
+	 if(ch >= '0' && ch < '8') {
 	    unsigned len;
 	    unsigned code;
 	    txt--;
@@ -890,3 +887,34 @@ void remove_tags(char *buf)
       buf=less;
    }
 }
+
+bool in_foreground_pgrp()
+{
+   static int tty_fd;
+   if(tty_fd==-1)
+      return true;
+   pid_t pg=tcgetpgrp(tty_fd);
+   if(pg==(pid_t)-1 && !isatty(tty_fd)) {
+      tty_fd=open("/dev/tty",O_RDONLY);
+      if(tty_fd==-1)
+	 return true;
+      pg=tcgetpgrp(tty_fd);
+   }
+   if(pg==(pid_t)-1 || pg==getpgrp())
+      return true;
+   return false;
+}
+
+void random_init()
+{
+   static bool init;
+   if(!init)
+   {
+      srandom(time(NULL)+getpid());
+      init=true;
+   }
+}
+double random01()
+{
+   return random()/2147483648.0;
+}
