@@ -1,11 +1,11 @@
 /*
  * lftp and utils
  *
- * Copyright (c) 1996-2005 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2010 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: misc.h,v 1.48 2007/09/10 09:30:20 lav Exp $ */
+/* $Id: misc.h,v 1.53 2010/04/29 11:00:43 lav Exp $ */
 
 #ifndef MISC_H
 #define MISC_H
@@ -62,6 +62,10 @@ void  truncate_file_tree(const char *dir);
 /* returns file descriptor terminal width; -1 on error, 0 on N/A */
 int fd_width(int fd);
 
+/* returns true if current pgrp is the foreground pgrp of controlling tty
+ * or if the fg pgrp is unknown */
+bool in_foreground_pgrp();
+
 // returns malloc'ed cwd no matter how long it is
 // returns 0 on error.
 char *xgetcwd();
@@ -124,15 +128,24 @@ static inline char *memrchr(char *buf,char c,size_t len) {
 const char *shell_encode(const char *);
 void remove_tags(char *buf);
 
+void random_init();
+double random01();
+
 #define ListAdd(type,chain,this,next)  \
 do {				       \
    this->next=chain;		       \
    chain=this;			       \
 } while(0)
 
+#define ListScan(type,chain,next) \
+   for(type *scan=chain; scan; scan=scan->next)
+
+#define ListScanPtr(type,chain,next) \
+   for(type **scan=&chain; *scan; scan=&scan[0]->next)
+
 #define ListDel(type,chain,this,next)			 \
 do {							 \
-   for(type **scan=&chain; *scan; scan=&scan[0]->next)	 \
+   ListScanPtr(type,chain,next)				 \
       if(*scan==this)					 \
       {							 \
 	 *scan=scan[0]->next;				 \
@@ -140,7 +153,4 @@ do {							 \
       }							 \
 } while(0)
 
-#define ListScan(type,chain,next) \
-   for(type *scan=chain; scan; scan=scan->next)
-
 #endif // MISC_H
