@@ -1,11 +1,11 @@
 /*
  * lftp and utils
  *
- * Copyright (c) 1996-1997 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2007 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -66,7 +66,7 @@ void  mvJob::PrintStatus(int v,const char *prefix)
    printf("%s[%s]\n",prefix,session->CurrentStatus());
 }
 
-void  mvJob::ShowRunStatus(StatusLine *s)
+void  mvJob::ShowRunStatus(const SMTaskRef<StatusLine>& s)
 {
    if(!Done())
       s->Show("[%s]",session->CurrentStatus());
