@@ -1,11 +1,11 @@
 /*
  * lftp and utils
  *
- * Copyright (c) 1996-2005 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2007 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: netrc.cc,v 1.14 2006/02/06 10:57:31 lav Exp $ */
+/* $Id: netrc.cc,v 1.17 2008/11/27 05:56:42 lav Exp $ */
 
 #include <config.h>
 
@@ -27,25 +27,8 @@
 #include <errno.h>
 #include "xstring.h"
 #include "netrc.h"
-#include "xmalloc.h"
 #include "log.h"
 
-NetRC::Entry::Entry(const char *h,const char *u,const char *p,const char *a)
-{
-   host=xstrdup(h);
-   user=xstrdup(u);
-   pass=xstrdup(p);
-   acct=xstrdup(a);
-}
-
-NetRC::Entry::~Entry()
-{
-   xfree(host);
-   xfree(user);
-   xfree(pass);
-   xfree(acct);
-}
-
 static bool comment(const char *s, FILE *f)
 {
    if(s[0]!='#')
