@@ -1,11 +1,11 @@
 /*
  * lftp and utils
  *
- * Copyright (c) 1996-2007 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2010 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -18,13 +18,14 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: pgetJob.cc,v 1.50 2008/05/27 07:57:38 lav Exp $ */
+/* $Id: pgetJob.cc,v 1.57 2010/04/29 11:00:43 lav Exp $ */
 
 #include <config.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <stddef.h>
 #include <assert.h>
+#include <errno.h>
 #include "pgetJob.h"
 #include "url.h"
 #include "misc.h"
@@ -323,9 +324,13 @@ pgetJob::pgetJob(FileCopy *c1,const char *n,int m)
 	 LoadStatus0();
    }
 }
-pgetJob::~pgetJob()
+void pgetJob::PrepareToDie()
 {
    free_chunks();
+   super::PrepareToDie();
+}
+pgetJob::~pgetJob()
+{
 }
 
 pgetJob::ChunkXfer *pgetJob::NewChunk(const char *remote,off_t start,off_t limit)
@@ -365,20 +370,20 @@ void pgetJob::SaveStatus()
       return;
 
    off_t size=GetSize();
-   fprintf(f,"size=%lld\n",size);
+   fprintf(f,"size=%lld\n",(long long)size);
 
    int i=0;
-   fprintf(f,"%d.pos=%lld\n",i,GetPos());
+   fprintf(f,"%d.pos=%lld\n",i,(long long)GetPos());
    if(!chunks)
       goto out_close;
-   fprintf(f,"%d.limit=%lld\n",i,limit0);
+   fprintf(f,"%d.limit=%lld\n",i,(long long)limit0);
    for(int chunk=0; chunk<chunks.count(); chunk++)
    {
       if(chunks[chunk]->Done())
 	 continue;
       i++;
-      fprintf(f,"%d.pos=%lld\n",i,chunks[chunk]->GetPos());
-      fprintf(f,"%d.limit=%lld\n",i,chunks[chunk]->limit);
+      fprintf(f,"%d.pos=%lld\n",i,(long long)chunks[chunk]->GetPos());
+      fprintf(f,"%d.limit=%lld\n",i,(long long)chunks[chunk]->limit);
    }
 out_close:
    fclose(f);
@@ -389,8 +394,18 @@ void pgetJob::LoadStatus0()
       return;
 
    FILE *f=fopen(status_file,"r");
-   if(!f)
+   if(!f) {
+      int saved_errno=errno;
+      // Probably the file is already complete
+      // or it was previously downloaded by plain get.
+      struct stat st;
+      if(stat(c->put->GetLocal()->full_name,&st)==-1)
+	 return;
+      Log::global->Format(0,"pget: %s: cannot open (%s), resuming at the file end\n",
+	 status_file.get(),strerror(saved_errno));
+      c->SetRange(st.st_size,FILE_END);
       return;
+   }
 
    long long size;
    if(fscanf(f,"size=%lld\n",&size)<1)
@@ -465,7 +480,7 @@ void pgetJob::LoadStatus()
       goto out_close;
    for(i=0; i<num_of_chunks; i++)
    {
-      ChunkXfer *c=NewChunk(GetName(),pos[i],limit[i]);
+      ChunkXfer *c=NewChunk(GetName(),pos[i+1],limit[i+1]);
       c->SetParentFg(this,false);
       chunks.append(c);
    }
