@@ -1,11 +1,11 @@
 /*
  * lftp and utils
  *
- * Copyright (c) 1999-2008 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1999-2010 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: resource.cc,v 1.151 2008/02/17 08:19:25 lav Exp $ */
+/* $Id: resource.cc,v 1.165 2010/04/29 11:00:44 lav Exp $ */
 
 #include <config.h>
 
@@ -35,8 +35,9 @@
 #include "url.h"
 #include "GetPass.h"
 #include "ascii_ctype.h"
-#include "confpaths.h"
+#include "configmake.h"
 #include "misc.h"
+#include "localcharset.h"
 
 static const char *FtpProxyValidate(xstring_c *p)
 {
@@ -61,9 +62,10 @@ static const char *FtpProxyValidate(xstring_c *p)
 
 static const char *FtpProxyAuthTypeValidate(xstring_c *s)
 {
-   if(s->ne("user") && s->ne("joined") && s->ne("joined-acct") && s->ne("open"))
+   if(s->ne("user") && s->ne("joined") && s->ne("joined-acct")
+   && s->ne("open") && s->ne("proxy-user@host"))
       // for translator: `user', `joined', `joined-acct', `open' are literals.
-      return _("ftp:proxy-auth-type must be one of: user, joined, joined-acct, open");
+      return _("ftp:proxy-auth-type must be one of: user, joined, joined-acct, open, proxy-user@host");
    return 0;
 }
 
@@ -190,6 +192,7 @@ static ResType lftp_vars[] = {
    {"ftp:passive-mode",		 "on",    ResMgr::BoolValidate,0},
    {"ftp:port-range",		 "full",  ResMgr::RangeValidate,0},
    {"ftp:port-ipv4",		 "",	  ResMgr::IPv4AddrValidate,0},
+   {"ftp:prefer-epsv",		 "no",	  ResMgr::BoolValidate,0},
    {"ftp:proxy",		 "",	  FtpProxyValidate,0},
    {"ftp:proxy-auth-type",	 "user",  FtpProxyAuthTypeValidate,0},
    {"ftp:rest-list",		 "no",	  ResMgr::BoolValidate,0},
@@ -208,10 +211,12 @@ static ResType lftp_vars[] = {
    {"ftp:ssl-use-ccc",		 "no",	  ResMgr::BoolValidate,0},
    {"ftp:ssl-shutdown-timeout",	 "5",	  ResMgr::TimeIntervalValidate,0},
    {"ftp:ssl-data-use-keys",	 "yes",	  ResMgr::BoolValidate,0},
+   {"ftp:ssl-copy-sid",		 "yes",	  ResMgr::BoolValidate,0},
    {"ftps:initial-prot",	 "",	  ProtValidate,0},
 #endif
    {"ftp:stat-interval",	 "1",	  ResMgr::TimeIntervalValidate,0},
    {"ftp:sync-mode",		 "on",    ResMgr::BoolValidate,0},
+   {"ftp:trust-feat",		 "no",	  ResMgr::BoolValidate,0},
    {"ftp:use-abor",		 "yes",   ResMgr::BoolValidate,0},
    {"ftp:use-allo",		 "yes",   ResMgr::BoolValidate,0},
    {"ftp:use-feat",		 "yes",   ResMgr::BoolValidate,0},
@@ -223,7 +228,8 @@ static ResType lftp_vars[] = {
    {"ftp:use-pret",		 "yes",   ResMgr::BoolValidate,0},
    {"ftp:use-site-chmod",	 "yes",   ResMgr::BoolValidate,0},
    {"ftp:use-site-idle",	 "no",    ResMgr::BoolValidate,0},
-   {"ftp:use-site-utime",	 "no",	  ResMgr::BoolValidate,0},
+   {"ftp:use-site-utime",	 "yes",	  ResMgr::BoolValidate,0},
+   {"ftp:use-site-utime2",	 "yes",	  ResMgr::BoolValidate,0},
    {"ftp:use-size",		 "yes",   ResMgr::BoolValidate,0},
    {"ftp:use-stat",		 "yes",   ResMgr::BoolValidate,0},
    {"ftp:use-stat-for-list",	 "no",	  ResMgr::BoolValidate,0},
@@ -235,7 +241,7 @@ static ResType lftp_vars[] = {
    {"ftp:waiting-150-timeout",	 "5",	  ResMgr::TimeIntervalValidate,0},
 #define RETRY_530 \
    "too many|overloaded|try (again |back )?later|is restricted to|"\
-   "maximum number|number of connect|only.*session.*allowed|more connection|already connected"
+   "maximum number|number of connect|only.*session.*allowed|more connection|already connected|simultaneous login"
    {"ftp:retry-530",		 RETRY_530,ResMgr::ERegExpValidate,0},
    {"ftp:retry-530-anonymous",	 "Login incorrect",ResMgr::ERegExpValidate,0},
    {"hftp:cache",		 "yes",   ResMgr::BoolValidate,0},
@@ -270,7 +276,7 @@ static ResType lftp_vars[] = {
    {"net:limit-rate",		 "0:0",   ResMgr::UNumberPairValidate,0},
    {"net:limit-total-max",	 "0",	  ResMgr::UNumberValidate,ResMgr::NoClosure},
    {"net:limit-total-rate",	 "0:0",   ResMgr::UNumberPairValidate,ResMgr::NoClosure},
-   {"net:max-retries",		 "4096",  ResMgr::UNumberValidate,0},
+   {"net:max-retries",		 "1000",  ResMgr::UNumberValidate,0},
    {"net:persist-retries",	 "0",	  ResMgr::UNumberValidate,0},
    {"net:no-proxy",		 "",	  0,ResMgr::NoClosure},
    {"net:reconnect-interval-base","30",	  ResMgr::UNumberValidate,0},
@@ -298,12 +304,12 @@ static ResType lftp_vars[] = {
 
    {"sftp:max-packets-in-flight","16",	  ResMgr::UNumberValidate,0},
    {"sftp:protocol-version",	 "4",	  ResMgr::UNumberValidate,0},
-   {"sftp:size-read",		 "0x8000",ResMgr::UNumberValidate,0},
-   {"sftp:size-write",		 "0x8000",ResMgr::UNumberValidate,0},
+   {"sftp:size-read",		 "32k",	  ResMgr::UNumberValidate,0},
+   {"sftp:size-write",		 "32k",	  ResMgr::UNumberValidate,0},
    {"sftp:connect-program",	 "ssh -a -x",0,0},
    {"sftp:server-program",	 "sftp",  0,0},
    {"sftp:charset",		 "",	  ResMgr::CharsetValidate,0},
-   {"sftp:use-full-path",	 "no",	  0,0},
+   {"sftp:use-full-path",	 "yes",	  ResMgr::BoolValidate,0},
 
    {"file:charset",		 "",	  ResMgr::CharsetValidate,ResMgr::NoClosure},
 
@@ -320,6 +326,9 @@ static ResType lftp_vars[] = {
    {"dns:order",		 DEFAULT_ORDER, OrderValidate,0},
    {"dns:SRV-query",		 "no",	  ResMgr::BoolValidate,0},
    {"dns:use-fork",		 "yes",	  ResMgr::BoolValidate,ResMgr::NoClosure},
+#ifdef DNSSEC_LOCAL_VALIDATION
+   {"dns:strict-dnssec",	 "no",	  ResMgr::BoolValidate,0},
+#endif
 
    {"fish:shell",		 "/bin/sh",0,0},
    {"fish:connect-program",	 "ssh -a -x",0,0},
@@ -331,6 +340,7 @@ static ResType lftp_vars[] = {
    {"xfer:verify",		 "no",	  ResMgr::BoolValidate,ResMgr::NoClosure},
    {"xfer:verify-command",	 "",	  ResMgr::FileExecutable,0},
    {"xfer:log",			 "yes",	  ResMgr::BoolValidate,ResMgr::NoClosure},
+   {"xfer:auto-rename",		 "no",	  ResMgr::BoolValidate,ResMgr::NoClosure},
 
 #if USE_SSL
    {"ssl:ca-file",		 "",	  ResMgr::FileReadable,ResMgr::NoClosure},
@@ -423,11 +433,9 @@ void ResMgr::ClassInit()
    if(dir_colors)
       Set("color:dir-colors",0,dir_colors);
 
-#if defined(HAVE_NL_LANGINFO) && defined(CODESET)
-   char *cs=nl_langinfo(CODESET);
-   if(cs)
+   const char *cs=locale_charset();
+   if(cs && cs[0])
       Set("file:charset",0,cs);
-#endif
 
    const char *time_style=getenv("TIME_STYLE");
    if(time_style && *time_style)
